<?php

namespace Drupal\vch\Plugin\views\style;

use Drupal\Core\Template\Attribute;
use Drupal\views\Plugin\views\style\StylePluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Style plugin for the Clean HTML view.
 *
 * @ViewsStyle(
 *   id = "clean_html_style",
 *   title = @Translation("Clean HTML Style"),
 *   help = @Translation("Displays content without HTML tags."),
 *   theme = "views_view_clean_html_style",
 *   display_types = {"normal"}
 * )
 */
class CleanHTMLStyle extends StylePluginBase {

  /**
   * Indicates whether the style plugin uses a row plugin.
   *
   * @var bool
   */
  protected $usesRowPlugin = TRUE;

  /**
   * Indicates whether the plugin allows for style options to be exposed.
   *
   * @var bool
   */
  protected $usesOptions = TRUE;


  /**
   * Defines the options for the CleanHTMLStyle plugin.
   *
   * @return array
   *   An array of options for the plugin.
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['wrapper_class'] = ['default' => ''];
    $options['row_class'] = ['default' => ''];
    return $options;
  }


  /**
   * Implements hook_views_style_options_form().
   *
   * Builds the options form for the CleanHTMLStyle plugin.
   *
   * @param array $form
   *   An associative array containing the form elements.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['wrapper_class'] = [
      '#title' => $this->t('Main wrapper class'),
      '#description' => $this->t('Additional classes for the main wrapper div around all rows.'),
      '#type' => 'textfield',
      '#default_value' => $this->options['wrapper_class'],
    ];

    $form['row_class'] = [
      '#title' => $this->t('Row class'),
      '#description' => $this->t('Additional classes for each row.'),
      '#type' => 'textfield',
      '#default_value' => $this->options['row_class'],
    ];
  }

 
  /**
   * Renders the view using the CleanHTMLStyle style plugin.
   *
   * @return array
   *   An array containing the rendered view.
   */
  public function render() {
    $rows = [];
    
    // Create main wrapper attributes and add main wrapper class.
    $main_wrapper_attributes = new Attribute();
    if (!empty($this->options['wrapper_class'])) {
      $main_wrapper_attributes->addClass($this->options['wrapper_class']);
    }

    foreach ($this->view->result as $row_index => $row) {
      $this->view->row_index = $row_index;

      // Render each row.
      $rendered_row = $this->view->rowPlugin->render($row);

      // Set up row attributes.
      $row_attributes = new Attribute();
      if (!empty($this->options['row_class'])) {
        $row_attributes->addClass($this->options['row_class']);
      }

      // Add each row's content and attributes to rows array.
      $rows[] = [
        'content' => $rendered_row,
        'row_attributes' => $row_attributes,
      ];
    }

    // Pass the main wrapper attributes and rows to the template.
    $rows['main_wrapper_attributes']= $main_wrapper_attributes;
    return [
      '#theme' => $this->themeFunctions(),
      '#rows' => $rows,
    ];
  }
}
